#
# hard-soft.R,  1 Oct 23
#
# Data from:
# Quantitative Assessment by Barry W. Boehm
# Datamation May 1973, page 49
# http://www.bitsavers.org/magazines/Datamation/197305.pdf
#
# SOFTWARE FOR TERMINAL-ORIENTED SYSTEMS by WERNER L. FRANK
# Datamation June 1968, page 30
# http://www.bitsavers.org/magazines/Datamation/196806.pdf
#
# FINAL REPORT OF THE JOINT LOGISTICS COMMANDERS' WORKSHOP ON
# POST DEPLOYMENT SOFTWARE SUPPORT FOR MISSION-CRITICAL COMPUTER SOFTWARE
# VOLUME II - WORKSHOP PROCEEDINGS JUNE 1984
# Page A-40

library("colorspace")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(2)


bo=read.csv("../hard-soft-boehm.csv")
fr=read.csv("../hard-soft-frank.csv")

plot(bo, type="l", col=pal_col[1], lwd=2.5,
	xaxs="i", yaxs="i",
	 xlim=c(1951,1985), ylim=c(0, 100),
	xlab="Year", ylab="Percentage")
lines(fr, col=pal_col[2], lwd=2.5)

text(1960, 80, "Hardware", cex=2)
text(1975, 40, "Software", cex=2)

legend("bottomright", legend=c("Boehm 1973", "Frank 1968"),
                        fill=pal_col, border="white", bty="n")

dev.copy(dev=png, file="boehm-frank-hard-soft.png")
dev.off()

# Fit a logistic equation
bo_mod=nls(percent ~ a+(b-a)/(1+exp((c-year)/d)), data=bo, trace=TRUE,
		start=list(a=5, b=80, c=1980, d=6))
summary(bo_mod)
pred=predict(bo_mod)
lines(bo$year, pred, col="blue")


dod=read.csv("dod-embedded.csv")
dod$elapsed=dod$year-1979
s_mod=glm(software ~ elapsed+I(elapsed^2), data=dod)
summary(s_mod)

#              Estimate Std. Error t value Pr(>|t|)    
# (Intercept)   3.67261    0.63775   5.759 0.000425 ***
# elapsed      -0.27238    0.24427  -1.115 0.297174    
# I(elapsed^2)  0.25355    0.01983  12.789 1.32e-06 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# (Dispersion parameter for gaussian family taken to be 0.3372392)
# 
#     Null deviance: 902.0440  on 10  degrees of freedom
# Residual deviance:   2.6979  on  8  degrees of freedom
# AIC: 23.757

h_mod=glm(hardware ~ elapsed+I(elapsed^2), data=dod)
summary(h_mod)

#              Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  1.315758   0.075034   17.54 1.14e-07 ***
# elapsed      0.039371   0.028738    1.37    0.208    
# I(elapsed^2) 0.033613   0.002333   14.41 5.26e-07 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# (Dispersion parameter for gaussian family taken to be 0.004668124)
# 
#     Null deviance: 22.567564  on 10  degrees of freedom
# Residual deviance:  0.037345  on  8  degrees of freedom
# AIC: -23.323

s_budget=function(year) 3.67-0.272*year+0.254*year^2
h_budget=function(year) 1.32+0.039*year+0.034*year^2

years=(1980:1990)-1979
plot(years+1979, 100*s_budget(years)/(s_budget(years)+h_budget(years)),
	xlab="Year", ylab="Software percentage")

